#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define MAX_SIZE 100 

/**
 * Allocates memory for a line of characters.
 * 
 * @return A pointer to the allocated memory.
 */
char* AllocateLine() {
    char *line = malloc(MAX_SIZE * sizeof(char));
    if (line == NULL) {
        printf("Failed to allocate memory\n");
        exit(1);
    }
    return line;
}

/**
 * Process a line of text.
 *
 * This function takes a line of text as input and updates the count of lines and characters.
 *
 * @param line The line of text to process.
 * @param countLines Pointer to the variable storing the count of lines.
 * @param countChars Pointer to the variable storing the count of characters.
 */
void ProcessLine(char *line, int *countGames, int *countPlayers, int *isFirstWhiteLine, int *lastLineIsWhite) {

    char *str = malloc(strlen(line));
    int num;

    line[strcspn(line, "\n")] = 0;

    if (line[0] == '\0' && *lastLineIsWhite && !*isFirstWhiteLine) {
        printf("%d %d", *countGames, *countPlayers);
        exit(0);
    } 

    if (line[0] == '\0' && !*isFirstWhiteLine && !*lastLineIsWhite) {
        (*countGames)++;
        *lastLineIsWhite = 1;
    }

    if (line[0] != '\0' && !*isFirstWhiteLine) {

        if (sscanf(line, "%[^:]:%d", str, &num) == 2)
            (*countPlayers)++;

        *lastLineIsWhite = 0;
    }

    if (line[0] == '\0' && *isFirstWhiteLine) {
        *isFirstWhiteLine = 0;
    } 
       
}

int main() {
    int countGames = 0, countPlayers = 0, isFirstWhiteLine = 1, lastLineIsWhite = 0;
    char *line = AllocateLine();

    while (fgets(line, MAX_SIZE, stdin) != NULL) {
        ProcessLine(line, &countGames, &countPlayers, &isFirstWhiteLine, &lastLineIsWhite);
    }

    printf("%d %d", countGames, countPlayers);
    
    free(line);
    return 0;
}